You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@syncope.apache.org by as...@apache.org on 2013/01/28 09:39:11 UTC

svn commit: r1439300 - in /syncope/trunk: client/src/main/java/org/apache/syncope/client/rest/utils/ core/src/main/java/org/apache/syncope/core/rest/utils/ core/src/test/java/org/apache/syncope/core/rest/jaxrs/

Author: ashakirin
Date: Mon Jan 28 08:39:11 2013
New Revision: 1439300

URL: http://svn.apache.org/viewvc?rev=1439300&view=rev
Log:
[SYNCOPE-289] JAXRS integration tests (currently not all tests are green, but shared to be visible for other committers)

Added:
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ConnectorTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/EntitlementTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/LoggerTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/NotificationTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/PolicyTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ReportTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ResourceTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/RoleTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/SchemaTestITCaseJAXRS.java   (with props)
    syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/UserRequestTestITCaseJAXRS.java   (with props)
Modified:
    syncope/trunk/client/src/main/java/org/apache/syncope/client/rest/utils/RestClientExceptionMapper.java
    syncope/trunk/core/src/main/java/org/apache/syncope/core/rest/utils/RestServiceExceptionMapper.java

Modified: syncope/trunk/client/src/main/java/org/apache/syncope/client/rest/utils/RestClientExceptionMapper.java
URL: http://svn.apache.org/viewvc/syncope/trunk/client/src/main/java/org/apache/syncope/client/rest/utils/RestClientExceptionMapper.java?rev=1439300&r1=1439299&r2=1439300&view=diff
==============================================================================
--- syncope/trunk/core/src/main/java/org/apache/syncope/core/rest/utils/RestServiceExceptionMapper.java (original)
+++ syncope/trunk/core/src/main/java/org/apache/syncope/core/rest/utils/RestServiceExceptionMapper.java Mon Jan 28 08:39:11 2013
@@ -187,7 +187,9 @@ public class RestServiceExceptionMapper 
         ResponseBuilder responseBuilder = Response.status(Response.Status.NOT_FOUND);
 
         if (ex instanceof javax.ws.rs.NotFoundException) {
-            response = buildResponse(responseBuilder, SyncopeClientExceptionType.NotFound, ex, null);
+            response = buildResponse(responseBuilder, SyncopeClientExceptionType.NotFound, (ex.getCause() != null)
+                    ? ex.getCause()
+                    : ex, null);
 
         } else if (ex instanceof NotFoundException) {
             response = buildResponse(responseBuilder, SyncopeClientExceptionType.NotFound, ex, null);
@@ -205,8 +207,8 @@ public class RestServiceExceptionMapper 
         ResponseBuilder responseBuilder = Response.status(Response.Status.BAD_REQUEST);
 
         if (ex instanceof javax.ws.rs.BadRequestException) {
-            response = buildResponse(responseBuilder, SyncopeClientExceptionType.Unknown, ex, null);
-        
+            throw (javax.ws.rs.BadRequestException) ex;
+            
         } else if (ex instanceof InvalidEntityException) {
             SyncopeClientExceptionType exType = SyncopeClientExceptionType.valueOf("Invalid"
                     + ((InvalidEntityException) ex).getEntityClassSimpleName());

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ConnectorTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ConnectorTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ConnectorTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ConnectorTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.ConfigurationTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class ConnectorTestITCaseJAXRS extends ConfigurationTestITCase {
+    
+    public ConnectorTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ConnectorTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/EntitlementTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/EntitlementTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/EntitlementTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/EntitlementTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.AuthenticationTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class EntitlementTestITCaseJAXRS extends AuthenticationTestITCase {
+    
+    public EntitlementTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/EntitlementTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/LoggerTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/LoggerTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/LoggerTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/LoggerTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.LoggerTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class LoggerTestITCaseJAXRS extends LoggerTestITCase {
+    
+    public LoggerTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/LoggerTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/NotificationTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/NotificationTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/NotificationTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/NotificationTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.NotificationTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class NotificationTestITCaseJAXRS extends NotificationTestITCase {
+    
+    public NotificationTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/NotificationTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/PolicyTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/PolicyTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/PolicyTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/PolicyTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.PolicyTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class PolicyTestITCaseJAXRS extends PolicyTestITCase {
+    
+    public PolicyTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/PolicyTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ReportTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ReportTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ReportTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ReportTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.ReportTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class ReportTestITCaseJAXRS extends ReportTestITCase {
+    
+    public ReportTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ReportTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ResourceTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ResourceTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ResourceTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ResourceTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.ResourceTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class ResourceTestITCaseJAXRS extends ResourceTestITCase {
+    
+    public ResourceTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/ResourceTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/RoleTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/RoleTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/RoleTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/RoleTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.RoleTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class RoleTestITCaseJAXRS extends RoleTestITCase {
+    
+    public RoleTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/RoleTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/SchemaTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/SchemaTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/SchemaTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/SchemaTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.SchemaTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class SchemaTestITCaseJAXRS extends SchemaTestITCase {
+    
+    public SchemaTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/SchemaTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Added: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/UserRequestTestITCaseJAXRS.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/UserRequestTestITCaseJAXRS.java?rev=1439300&view=auto
==============================================================================
--- syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/UserRequestTestITCaseJAXRS.java (added)
+++ syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/UserRequestTestITCaseJAXRS.java Mon Jan 28 08:39:11 2013
@@ -0,0 +1,31 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+package org.apache.syncope.core.rest.jaxrs;
+
+import org.apache.syncope.core.rest.UserRequestTestITCase;
+import org.junit.FixMethodOrder;
+import org.junit.runners.MethodSorters;
+
+@FixMethodOrder(MethodSorters.JVM)
+public class UserRequestTestITCaseJAXRS extends UserRequestTestITCase {
+    
+    public UserRequestTestITCaseJAXRS() {
+       setEnabledCXF(true);
+    }
+}

Propchange: syncope/trunk/core/src/test/java/org/apache/syncope/core/rest/jaxrs/UserRequestTestITCaseJAXRS.java
------------------------------------------------------------------------------
    svn:mime-type = text/plain
--- syncope/trunk/client/src/main/java/org/apache/syncope/client/rest/utils/RestClientExceptionMapper.java (original)
+++ syncope/trunk/client/src/main/java/org/apache/syncope/client/rest/utils/RestClientExceptionMapper.java Mon Jan 28 08:39:11 2013
@@ -24,6 +24,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
+import javax.ws.rs.BadRequestException;
 import javax.ws.rs.core.Response;
 import javax.ws.rs.ext.ExceptionMapper;
 import javax.ws.rs.ext.Provider;
@@ -66,8 +67,12 @@ public class RestClientExceptionMapper i
 		} else if (statusCode == HttpStatus.SC_UNAUTHORIZED) {
 			ex = new AccessControlException("Remote unauthorized exception");
 			
-		} else {
-			// 3. All other codes are mapped to runtime exception with HTTP code information 
+            // 3. Map  SC_BAD_REQUEST
+        } else if (statusCode == HttpStatus.SC_BAD_REQUEST) {
+            ex = new BadRequestException();
+
+        } else {
+			// 4. All other codes are mapped to runtime exception with HTTP code information 
 			ex = new RuntimeException(String.format(
 					"Remote exception with status code: %s",
 					Response.Status.fromStatusCode(statusCode).name()));

Modified: syncope/trunk/core/src/main/java/org/apache/syncope/core/rest/utils/RestServiceExceptionMapper.java
URL: http://svn.apache.org/viewvc/syncope/trunk/core/src/main/java/org/apache/syncope/core/rest/utils/RestServiceExceptionMapper.java?rev=1439300&r1=1439299&r2=1439300&view=diff
==============================================================================